summaryrefslogtreecommitdiff
path: root/lib/config/default.js
diff options
context:
space:
mode:
Diffstat (limited to 'lib/config/default.js')
-rw-r--r--lib/config/default.js12
1 files changed, 11 insertions, 1 deletions
diff --git a/lib/config/default.js b/lib/config/default.js
index 68849d36..1b124b3e 100644
--- a/lib/config/default.js
+++ b/lib/config/default.js
@@ -56,7 +56,7 @@ module.exports = {
heartbeatTimeout: 10000,
// document
documentMaxLength: 100000,
// image upload setting, available options are imgur/s3/filesystem
imageUploadType: 'filesystem',
imgur: {
clientID: undefined
@@ -74,7 +74,17 @@ module.exports = {
port: 9000
},
s3bucket: undefined,
+ azure: {
+ connectionString: undefined,
+ container: undefined
+ },
// authentication
+ oauth2: {
+ authorizationURL: undefined,
+ tokenURL: undefined,
+ clientID: undefined,
+ clientSecret: undefined
+ },
facebook: {
clientID: undefined,
clientSecret: undefined
@@ -56,7 +56,7 @@ module.exports = {
// document
documentMaxLength: 100000,
- // image upload setting, available options are imgur/s3/filesystem
+ // image upload setting, available options are imgur/s3/filesystem/azure
imageUploadType: 'filesystem',
imgur: {